// AUTO-GENERATED BY UpdateGenVersion.bat 333d9d07ed28d1151e383b669f900dcb34870d1c
const char GenVersion_Version[] = "0.4.4-dev";
const char GenVersion_Commit[] = "333d9d07ed28d1151e383b669f900dcb34870d1c";
